@@ -8,6 +8,7 @@ import pandas as pd
 import geopandas as gpd
 from tqdm import tqdm
 import PySimpleGUI as sg
+from shapely.wkb import loads
 from shapely.geometry import Polygon
 from shapely.ops import cascaded_union, unary_union, nearest_points
 pd.options.mode.chained_assignment = None
@@ -185,14 +186,22 @@ class hexagon_grid:
             area_thres = (spacing*spacing)*0.33
             hexagon = dissolve_polygon(final_hexa, area_thres).geosolution
             df = hexagon.explode().reset_index().drop(['level_0', 'level_1'], axis = 1)
-            check_topology(df)
-            self.geosolution = df
+            gdf = gpd.overlay(data, df, how="union")
+            gdf["geometry"] = gdf["geometry"].apply(lambda geom: geom.wkb)
+            gdf = gdf.drop_duplicates(["geometry"])
+            gdf["geometry"] = gdf["geometry"].apply(lambda geom: loads(geom))
+            check_topology(gdf)
+            self.geosolution = gdf
         elif 0.0 < self.area_threshold <= 0.8:
             area_thres = (spacing*spacing)*self.area_threshold
             hexagon = dissolve_polygon(final_hexa, area_thres).geosolution
             df = hexagon.explode().reset_index().drop(['level_0', 'level_1'], axis = 1)
-            check_topology(df)
-            self.geosolution = df
+            gdf = gpd.overlay(data, df, how="union")
+            gdf["geometry"] = gdf["geometry"].apply(lambda geom: geom.wkb)
+            gdf = gdf.drop_duplicates(["geometry"])
+            gdf["geometry"] = gdf["geometry"].apply(lambda geom: loads(geom))
+            check_topology(gdf)
+            self.geosolution = gdf
         else:
             raise ValueError("You shouldn't cross the upper/lower limit of area threshold.\nThreshold should be 0.0> area_threshold>=0.8")
 
